pub enum PageLayout {
SinglePage,
OneColumn,
TwoColumnLeft,
TwoColumnRight,
TwoPageLeft,
TwoPageRight,
}Expand description
Page layout modes
Variants
SinglePage
Display one page at a time
OneColumn
Display pages in one column
TwoColumnLeft
Display pages in two columns, odd-numbered pages on the left
TwoColumnRight
Display pages in two columns, odd-numbered pages on the right
TwoPageLeft
Display pages in two columns, cover page displayed alone
TwoPageRight
Display pages in two columns, cover page displayed alone
Implementations
Sourceimpl PageLayout
impl PageLayout
Sourcepub fn to_pdf_name(&self) -> &'static str
pub fn to_pdf_name(&self) -> &'static str
Convert to PDF name